;===============================================
;
; 100kHz Bustakt
; MT + MR
; Adresse vom LM75 = 1001001x ( 0=write / 1=read )
; PTR-Register fr die Temperatur = 0x00
;
; Vorgang (* bedeutet erledigt):
;  0. TWI initialisieren 
;  1. Startbedingung setzen
;  2. Slave-Write-Adresse senden
;  3. ACK vom Slave abfragen (wenn ok dann weiter mit 4., ansonsten ERROR)
;  4. PTR-Register auswhlen
;  5. ACK vom Slave abfragen (wenn ok dann weiter mit 6., ansonsten ERROR)
;  6. Stopbedingung setzen
;  7. warten
;  8. Startbedingung setzen
;  9. Slave-Write-Adresse senden
; 10. ACK vom Slave abfragen (wenn ok dann weiter mit 11., ansonsten ERROR)
; 11. umschalter auf Master-Reciver (MR)
; 12. Datenpaket 1 empfangen
; 13. Datenpaket 1 ausgeben (evtl. Komplement bilden)
; 14. Master ACK senden
; 15. Datenpaket 2 empfangen
; 16. Master NAK senden
; 17. Stopbedingung setzen
;
; Welche Register sind beteiligt?
; 1.
; 2.
; 3.
;
;===============================================
;=       Register in Benutzung                 =
;===============================================
;
;	 R0 =				R16 = temp 
;	 R1 =				R17 = Timerzhler
;	 R2 =				R18 = URAT bertragungsregister
;	 R3 =				R19 = Status Byte
;	 R4 =				R20 =
;	 R5 =				R21 =
;	 R6 =				R22 =
;	 R7 =				R23 =
;	 R8 =				R24 =
;	 R9 =				R25 =
;	R10 = ADD-Wert		R26 =
;	R11 = ADD-Wert		R27 =
;	R12 = 				R28 =
;	R13 =				R29 =
;	R14 =				R30 =
;	R15 =				R31 =
;


;===============================================
;= Include-Dateien                             =
;===============================================
.include "m8def.inc"

;===============================================
;= Definitionen + Initialisierung              =
;===============================================
.def ASCII_1		= r10
.def ASCII_2		= r11
.def Status			= r19

	ldi r16, 0x30
	mov ASCII_1, r16

	ldi r16, 0x37
	mov ASCII_2, r16

	clr Status
;===============================================
;= RESET-Routinen                              =
;===============================================
RESET:                        
;===============================================
;= Initialisierungen                           =
;===============================================
;STACK initialisieren
	ldi r16, LOW(RAMEND)
    out SPL, r16
    ldi r16, HIGH(RAMEND)
    out SPH, r16
;Ports initialisieren
	ldi r16, 0xff
	out DDRB, r16
	ldi r16, 0xf0
	out portc, r16
;Schnittstellen initialisieren
	rcall URAT_INIT
	rcall TWI_INIT
;-----------------------------------------------
	rcall TWI_START
	rcall TWI_SlaveWriteAdresse
	rcall TWI_Daten_schreiben
	rcall TWI_STOP
	rcall rs_trennung			;wg. der bersichtlichkeit
	rcall TWI_START
	rcall TWI_SlaveReadAdresse
	rcall TWI_Daten_lesen	
	rcall TWI_Daten_lesen
	rcall TWI_MR_NAK
	rcall TWI_STOP
	rcall rs_trennung			;wg. der bersichtlichkeit
	rcall rs_trennung			;wg. der bersichtlichkeit
;===============================================
;= Hauptroutine                                =
;===============================================
main:

	ldi r16, 0xf0
	out portb, r16
	rcall warte_1s

	ldi r16, 0x0f
	out portb, r16
	rcall warte_1s

rjmp main


;===============================================
;= Addon-Include-Dateien                       =
;===============================================
.include "URAT_Debug.asm"
.include "TWI_Lib.asm"
.include "Timer_Lib.asm"

