;===============================================
;= TWI Initialization                          =
;===============================================
.equ Start			= 0x08
.equ MT_SLA_ACK		= 0x18
.equ MT_DATA_ACK	= 0x28
.equ MR_SLA_ACK		= 0x40
.equ MR_DATA_ACK	= 0x50
.equ MR_DATA_NAK	= 0x58

TWI_INIT:					;Init fr 100kHz
	ldi r16, 32
	out TWBR, r16			;Bit Rate Register laden
	ldi r16, (0<<TWPS1)|(0<<TWPS0)
	out TWSR, r16			;Prescaler laden
	rcall rs_i2c_ini		;Debug Ausgabe
ret
;===============================================
;= Start senden                                =
;===============================================
TWI_START:	
	ldi r16, (1<<TWINT)|(1<<TWSTA)|(1<<TWEN)
	out TWCR, r16			;sende Startkondition
	rcall rs_i2c_start		;Debug ausgabe
	rcall TWI_wait
;-----------------------------------------------
	in Status, TWSR
	andi Status, 0xf8
	rcall rs_i2c_status		;Debug Ausgabe
	cpi Status, Start
	brne Fehler
ret
;===============================================
;= Slave Write Adresse bermitteln             =
;===============================================
TWI_SlaveWriteAdresse:
	ldi r16, 0b10010010		;LM75 Schreib-Adresse
	out TWDR, r16			
	ldi r16, (1<<TWINT)|(1<<TWEN)	
	out TWCR, r16			;starte bermittlung
	rcall rs_i2c_slave		;Debug Ausgabe
	rcall TWI_wait	
;-----------------------------------------------
	in Status, TWSR
	andi Status, 0xf8
	rcall rs_i2c_status		;Debug Ausgabe
	cpi Status, MT_SLA_ACK
	brne Fehler
ret
;===============================================
;= Slave Read Adresse bermitteln              =
;===============================================
TWI_SlaveReadAdresse:
	ldi r16, 0b10010011		;LM75 Lese-Adresse
	out TWDR, r16			
	ldi r16, (1<<TWINT)|(1<<TWEN)	
	out TWCR, r16			;starte bermittlung
	rcall rs_i2c_slave		;Debug Ausgabe
	rcall TWI_wait	
;-----------------------------------------------
	in Status, TWSR
	andi Status, 0xf8
	rcall rs_i2c_status		;Debug Ausgabe
	cpi Status, MR_SLA_ACK
	brne Fehler
ret
;===============================================
;= Daten bermitteln                           =
;===============================================
TWI_Daten_schreiben:
	ldi r16, 0x00			;Poniter-Register $00
	out TWDR, r16
	ldi r16, (1<<TWINT)|(1<<TWEN)	
	out TWCR, r16			;starte bermittlung
	rcall rs_i2c_senden		;Debug Ausgabe
	rcall TWI_wait
;-----------------------------------------------
	in Status, TWSR
	andi Status, 0xf8
	rcall rs_i2c_status		;Debug Ausgabe
	cpi Status, MT_DATA_ACK
	brne Fehler
ret
;===============================================
;= Daten empfangen                             =
;===============================================
TWI_Daten_lesen:
	ldi r16, (1<<TWINT)|(1<<TWEN)	
	out TWCR, r16			;starte bermittlung
	rcall TWI_wait
;-----------------------------------------------
	in Status, TWDR
	rcall rs_i2c_empfang	;Debug Ausgabe
	rcall rs_i2c_daten		;Debug Ausgabe
ret
;===============================================
;= MR-NAK senden                               =
;===============================================
TWI_MR_NAK:
	in Status, TWSR
	andi Status, 0xf8
	rcall rs_i2c_status		;Debug Ausgabe
	cpi Status, MR_DATA_NAK
	brne Fehler
ret
;===============================================
;= Stop senden                                =
;===============================================
TWI_STOP:
	ldi r16, (1<<TWINT)|(1<<TWSTO)|(1<<TWEN)
	out TWCR, r16			;sende Startkondition
	rcall rs_i2c_stop		;Debug ausgabe
ret
;===============================================
;= TWINT Flag abwarten                         =
;===============================================
TWI_wait:
	in r16, TWCR
	sbrs r16, TWINT
	rjmp TWI_wait
ret
;===============================================
;= Fehler                                      =
;===============================================
Fehler:
	rcall rs_i2c_fehler		;Debug Ausgabe
rjmp main
